ProjectConfig class

Constructors

ProjectConfig({required String appName, required String displayName, required String androidPackage, required String iosBundleId, required StateManagement stateManagement, required bool useFirebase, required bool useSecretKey, StateManagementArchitecture? blocArchitecture, StateManagementArchitecture? riverpodArchitecture})

Properties

androidPackage → String
final
appDisplayName → String
no setter
appName → String
final
blocArchitecture → StateManagementArchitecture?
final
displayName → String
final
environments → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
iosBundleId → String
final
projectPath → String
no setter
riverpodArchitecture → StateManagementArchitecture?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateManagement → StateManagement
final
useFirebase → bool
final
useSecretKey → bool
Whether to use SecureCompressor + secret_key_scrypt_generator for encrypted env files and encrypted local storage. When false, env files are read as plain text and StorageHelper stores data without key-value encryption.
final

Methods

androidPackageForEnv(String env) → String
iosBundleIdForEnv(String env) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited