useSecretKey property

bool useSecretKey
final

Whether to use SecureCompressor + secret_key_scrypt_generator for encrypted env files and encrypted local storage. When false, env files are read as plain text and StorageHelper stores data without key-value encryption.

Implementation

final bool useSecretKey;